summaryrefslogtreecommitdiffstats
path: root/mimelib/mimelib
diff options
context:
space:
mode:
Diffstat (limited to 'mimelib/mimelib')
-rw-r--r--mimelib/mimelib/addrlist.h2
-rw-r--r--mimelib/mimelib/body.h16
-rw-r--r--mimelib/mimelib/bodypart.h4
-rw-r--r--mimelib/mimelib/entity.h6
-rw-r--r--mimelib/mimelib/field.h16
-rw-r--r--mimelib/mimelib/fieldbdy.h2
-rw-r--r--mimelib/mimelib/group.h4
-rw-r--r--mimelib/mimelib/headers.h8
-rw-r--r--mimelib/mimelib/mailbox.h6
-rw-r--r--mimelib/mimelib/mboxlist.h2
-rw-r--r--mimelib/mimelib/mediatyp.h2
-rw-r--r--mimelib/mimelib/message.h6
-rw-r--r--mimelib/mimelib/msgcmp.h4
-rw-r--r--mimelib/mimelib/msgid.h2
-rw-r--r--mimelib/mimelib/nntp.h2
-rw-r--r--mimelib/mimelib/string.h18
16 files changed, 50 insertions, 50 deletions
diff --git a/mimelib/mimelib/addrlist.h b/mimelib/mimelib/addrlist.h
index 5d26736a..1225494d 100644
--- a/mimelib/mimelib/addrlist.h
+++ b/mimelib/mimelib/addrlist.h
@@ -32,7 +32,7 @@
//+ Description
//. {\tt DwAddressList} represents a list of {\it addresses} as described
//. in RFC-822. In MIME++, {\tt DwAddressList} is a container for objects
-//. of type {\tt DwAddress}, and it contains various member functions
+//. of type {\tt DwAddress}, and it tqcontains various member functions
//. to manage its contained objects. {\tt DwAddressList} is also a
//. {\tt DwFieldBody}. This reflects the fact that certain RFC-822 header
//. fields, such as the ``To'' header field, have a list of addresses
diff --git a/mimelib/mimelib/body.h b/mimelib/mimelib/body.h
index 2133a724..f19efa0c 100644
--- a/mimelib/mimelib/body.h
+++ b/mimelib/mimelib/body.h
@@ -46,9 +46,9 @@ class DwBodyPart;
//. is always part of an {\it entity}, which could be either a {\it message}
//. or a {\it body part}. An entity has a collection of {\it header fields}
//. and a body. If the content type of a body is ``multipart,'' then the
-//. body contains one or more body parts. If the content type is ``message,''
-//. then the body contains an encapsulated message. In all content types,
-//. the body contains a string of characters.
+//. body tqcontains one or more body parts. If the content type is ``message,''
+//. then the body tqcontains an encapsulated message. In all content types,
+//. the body tqcontains a string of characters.
//.
//. In MIME++, a {\tt DwBody} object is contained in a {\tt DwEntity} object.
//. The {\tt DwBody} object may contain a discrete body consisting only of a
@@ -56,14 +56,14 @@ class DwBodyPart;
//. contained {\tt DwBodyPart} objects or a single contained {\tt DwMessage}
//. object. The only reliable way to determine the type of {\tt DwBody} is
//. to access the Content-Type header field from the {\tt DwHeaders} object
-//. of the {\tt DwEntity} that contains it. For this reason, a {\tt DwBody}
+//. of the {\tt DwEntity} that tqcontains it. For this reason, a {\tt DwBody}
//. should always be part of a {\tt DwEntity}.
//.
//. In the tree (broken-down) representation of a message, a {\tt DwBody}
//. object can be an intermediate node, having both a parent node and
//. one or more child nodes, or a leaf node, having a parent but no child
//. nodes. In either case, the parent node is the {\tt DwEntity} object
-//. that contains it. If it is an intermediate node, it must be of type
+//. that tqcontains it. If it is an intermediate node, it must be of type
//. multipart with {\tt DwBodyPart} objects as child nodes, or of type
//. message with a single {\tt DwMessage} object as its child node.
//.
@@ -145,14 +145,14 @@ public:
//. from the broken-down representation. Only {\tt DwBody} objects
//. with content type of multipart or message require assembling.
//. In either case, the {\tt DwBody} object must be able to find the
- //. headers of the message or body part that contains it. Therefore,
+ //. headers of the message or body part that tqcontains it. Therefore,
//. if the {\tt DwBody} object is not the child of a {\tt DwEntity}
//. ({\it i.e.}, {\tt DwMessage} or {\tt DwBodyPart}) object, the
//. {\tt DwBody} cannot be assembled because the content type cannot
//. be determined.
//.
//. This function calls the {\tt Parse()} member function of any
- //. {\tt DwBodyPart} or {\tt DwMessage} object it contains.
+ //. {\tt DwBodyPart} or {\tt DwMessage} object it tqcontains.
//.
//. You should call this member function after you add a {\tt DwBodyPart}
//. object to a multipart body, or add a {\tt DwMessage} object to a
@@ -189,7 +189,7 @@ public:
void SetMessage(DwMessage* aMessage);
//. For a {\tt DwBody} with content type of message, this member function
- //. sets the {\tt DwMessage} object it contains.
+ //. sets the {\tt DwMessage} object it tqcontains.
static DwBody* NewBody(const DwString& aStr, DwMessageComponent* aParent);
//. Creates a new {\tt DwBody} object on the free store.
diff --git a/mimelib/mimelib/bodypart.h b/mimelib/mimelib/bodypart.h
index 9ed7f672..78e0db59 100644
--- a/mimelib/mimelib/bodypart.h
+++ b/mimelib/mimelib/bodypart.h
@@ -49,7 +49,7 @@ class DwBody;
//. in that a body part is part of a multipart body.
//.
//. In MIME++, a {\tt DwBodyPart} is a subclass of {\tt DwEntity}; therefore,
-//. it contains both a {\tt DwHeaders} object and a {\tt DwBody} object,
+//. it tqcontains both a {\tt DwHeaders} object and a {\tt DwBody} object,
//. and it is contained in a multipart {\tt DwBody} object.
//.
//. As with {\tt DwMessage}, most of the functionality of {\tt DwBodyPart} is
@@ -114,7 +114,7 @@ public:
//. This advanced function sets {\tt aPart} as the next {\tt DwBodyPart}
//. object following this {\tt DwBodyPart} in the list of {\tt DwBodyPart}
//. objects contained in a multipart {\tt DwBody}. Since {\tt DwBody}
- //. contains a member function for adding a {\tt DwBodyPart} object to
+ //. tqcontains a member function for adding a {\tt DwBodyPart} object to
//. its list, this function should be avoided for most applications.
//+ Var sNewBodyPart
diff --git a/mimelib/mimelib/entity.h b/mimelib/mimelib/entity.h
index e809c282..1bb4662b 100644
--- a/mimelib/mimelib/entity.h
+++ b/mimelib/mimelib/entity.h
@@ -44,7 +44,7 @@ class DwBody;
//. RFC-2045 defines an {\it entity} as either a {\it message} or a
//. {\it body part}, both of which have a collection of headers and
//. a {\it body}. In MIME++, an entity is represented by the class
-//. {\tt DwEntity}, which contains both a {\tt DwHeaders} object and
+//. {\tt DwEntity}, which tqcontains both a {\tt DwHeaders} object and
//. a {\tt DwBody} object.
//.
//. In the tree (broken-down) representation of message, a {\tt DwEntity}
@@ -53,7 +53,7 @@ class DwBody;
//. A {\tt DwEntity} object that is a root node must also be a {\tt DwMessage}
//. object. If a {\tt DwEntity} object is an intermediate node, its parent
//. must be a {\tt DwBody} object. The child nodes of a {\tt DwEntity}
-//. object are the {\tt DwHeaders} and {\tt DwBody} objects it contains.
+//. object are the {\tt DwHeaders} and {\tt DwBody} objects it tqcontains.
//.
//. Since {\tt DwEntity} is an abstract base class, you cannot create
//. instances of it directly. {\tt DwEntity} has two derived classes,
@@ -101,7 +101,7 @@ public:
//. method creates or updates the broken-down representation from the
//. string representation. For {\tt DwEntity} objects, the parse
//. method parses the string representation and sets the values of
- //. the {\tt DwHeaders} and {\tt DwBody} objects it contains. This
+ //. the {\tt DwHeaders} and {\tt DwBody} objects it tqcontains. This
//. member function also calls the {\tt Parse()} member functions
//. of the contained {\tt DwHeaders} and {\tt DwBody} objects.
//.
diff --git a/mimelib/mimelib/field.h b/mimelib/mimelib/field.h
index 9ada823c..7cd8f97c 100644
--- a/mimelib/mimelib/field.h
+++ b/mimelib/mimelib/field.h
@@ -44,16 +44,16 @@ class DwFieldBody;
//+ Name DwField -- Class representing a MIME header field
//+ Description
//. {\tt DwField} represents a header field as described in RFC-822.
-//. According to RFC-822, a field contains a field name and a field body.
-//. In MIME++, a {\tt DwField} contains three elements: a {\tt DwString}
-//. that contains its field name, a {\tt DwString} that contains its
-//. field body, and a {\tt DwFieldBody} object that contains a broken-down
+//. According to RFC-822, a field tqcontains a field name and a field body.
+//. In MIME++, a {\tt DwField} tqcontains three elements: a {\tt DwString}
+//. that tqcontains its field name, a {\tt DwString} that tqcontains its
+//. field body, and a {\tt DwFieldBody} object that tqcontains a broken-down
//. (that is, parsed) version of its field body.
//.
//. In the tree (broken-down) representation of message, a {\tt DwField}
//. object is always an intermediate node, having a parent node and a single
-//. child node. The parent node is the {\tt DwHeaders} object that contains
-//. it. The child node is the {\tt DwFieldBody} object it contains.
+//. child node. The parent node is the {\tt DwHeaders} object that tqcontains
+//. it. The child node is the {\tt DwFieldBody} object it tqcontains.
//.
//. To get and set the field name, use the member functions
//. {\tt FieldNameStr()} and {\tt SetFieldNameStr()}.
@@ -169,7 +169,7 @@ public:
void SetNext(const DwField* aField);
//. This {\it advanced} function sets {\tt aField} as the next field
//. following this field in the list of fields contained in the headers.
- //. Since {\tt DwHeaders} contains member functions for adding
+ //. Since {\tt DwHeaders} tqcontains member functions for adding
//. {\tt DwField} objects to its list, this function should be
//. avoided for most applications.
@@ -190,7 +190,7 @@ public:
//. {\tt DwFieldBody} object for this particular field. A typical
//. scenario might go as follows:
//. This member function examines the field name for this field,
- //. finds that it contains "To", creates a {\tt DwAddressList} object
+ //. finds that it tqcontains "To", creates a {\tt DwAddressList} object
//. to contain the field body, calls the {\tt Parse()} member
//. function for the {\tt DwAddressList}, and sets the {\tt DwAddressList}
//. object as this {\tt DwField} object's {\tt DwFieldBody}.
diff --git a/mimelib/mimelib/fieldbdy.h b/mimelib/mimelib/fieldbdy.h
index e5f3243a..24a0c0b9 100644
--- a/mimelib/mimelib/fieldbdy.h
+++ b/mimelib/mimelib/fieldbdy.h
@@ -47,7 +47,7 @@
//. In the tree (broken-down) representation of a message, a {\tt DwFieldBody}
//. object may be either a leaf node, having a parent but no child nodes, or
//. an intermediate node, having a parent and one or more child nodes. The
-//. parent node is the {\tt DwField} object that contains it. Child nodes,
+//. parent node is the {\tt DwField} object that tqcontains it. Child nodes,
//. if present, depend on the particular subclass of {\tt DwFieldBody} that
//. is instantiated. A {\tt DwAddressList} object, for example, has
//. {\tt DwAddress} objects as its child nodes.
diff --git a/mimelib/mimelib/group.h b/mimelib/mimelib/group.h
index 21cf930b..ea0e7260 100644
--- a/mimelib/mimelib/group.h
+++ b/mimelib/mimelib/group.h
@@ -47,8 +47,8 @@
//+ Name DwGroup -- Class representing an RFC-822 address group
//+ Description
//. {\tt DwGroup} represents a {\it group} as described in RFC-822. A group
-//. contains a group name and a (possibly empty) list of {\it mailboxes}.
-//. In MIME++, a {\tt DwGroup} object contains a string for the group name
+//. tqcontains a group name and a (possibly empty) list of {\it mailboxes}.
+//. In MIME++, a {\tt DwGroup} object tqcontains a string for the group name
//. and a {\tt DwMailboxList} object for the list of mailboxes.
//.
//. In the tree (broken-down) representation of message, a {\tt DwGroup}
diff --git a/mimelib/mimelib/headers.h b/mimelib/mimelib/headers.h
index f545a3db..5debab9b 100644
--- a/mimelib/mimelib/headers.h
+++ b/mimelib/mimelib/headers.h
@@ -87,7 +87,7 @@ class DwText;
//.
//. In the tree (broken-down) representation of a message, a {\tt DwHeaders}
//. object is an intermediate node, having both a parent node and several
-//. child nodes. The parent node is the {\tt DwEntity} object that contains
+//. child nodes. The parent node is the {\tt DwEntity} object that tqcontains
//. it. The child nodes are the {\tt DwField} objects in the list it manages.
//. (See the man page for {\tt DwMessageComponent} for a discussion of
//. the tree representation of a message.)
@@ -97,7 +97,7 @@ class DwText;
//. which creates the {\tt DwHeaders} object for you.
//.
//. While {\tt DwHeaders} has public member functions for managing the list
-//. of {\tt DwField} objects it contains, you will normally use convenience
+//. of {\tt DwField} objects it tqcontains, you will normally use convenience
//. functions to access the field bodies of the header fields directly.
//. You can access the field body for a specific well-known header field
//. by using the member function {\tt <Field>()}, where {\tt <Field>} is
@@ -347,7 +347,7 @@ public:
void AddOrReplaceField(DwField* aField);
//. Adds a {\tt DwField} object to the list. If a header field with
- //. the same field name already exists, it is replaced by the new
+ //. the same field name already exists, it is tqreplaced by the new
//. header field.
//.
//. {\tt DwHeaders} takes responsibility for deleting the added
@@ -359,7 +359,7 @@ public:
void AddField(DwField* aField);
//. Adds a {\tt DwField} object to the list. If a header field with
- //. the same field name already exists, it is {\it not} replaced;
+ //. the same field name already exists, it is {\it not} tqreplaced;
//. thus, duplicate header fields may occur when using this member
//. function. (This is what you want for some header fields, such as
//. the "Received" header field).
diff --git a/mimelib/mimelib/mailbox.h b/mimelib/mimelib/mailbox.h
index 7e38ae4b..2ef28258 100644
--- a/mimelib/mimelib/mailbox.h
+++ b/mimelib/mimelib/mailbox.h
@@ -41,7 +41,7 @@
//+ Description
//. RFC-822 defines a {\it mailbox} as an entity that can be the recipient
//. of a message. A mailbox is more specific than an {\it address}, which
-//. may be either a mailbox or a {\it group}. An RFC-822 mailbox contains
+//. may be either a mailbox or a {\it group}. An RFC-822 mailbox tqcontains
//. a full name, a {\it local-part}, an optional {\it route}, and a
//. {\it domain}. For example, in the mailbox
//.
@@ -53,7 +53,7 @@
//.
//. In MIME++, an RFC-822 mailbox is represented by a {\tt DwMailbox} object.
//. {\tt DwMailbox} is a subclass of {\tt DwAddress}, which reflects the
-//. fact that a mailbox is also an address. A {\tt DwMailbox} contains
+//. fact that a mailbox is also an address. A {\tt DwMailbox} tqcontains
//. strings representing the full name, local-part, route, and domain
//. of a mailbox.
//.
@@ -63,7 +63,7 @@
//. {\tt DwMailboxList} object.
//.
//. {\tt DwMailbox} has member functions for getting or setting the strings
-//. it contains.
+//. it tqcontains.
//.
//. {\tt DwMailbox} object can be included in a list of {\tt DwMailbox}
//. objects. To get the next {\tt DwMailbox} object in a list, use the
diff --git a/mimelib/mimelib/mboxlist.h b/mimelib/mimelib/mboxlist.h
index 723a8c55..adbd9363 100644
--- a/mimelib/mimelib/mboxlist.h
+++ b/mimelib/mimelib/mboxlist.h
@@ -42,7 +42,7 @@
//+ Description
//. {\tt DwMailboxList} represents a list of {\it mailboxes} as described
//. in RFC-822. In MIME++, {\tt DwMailboxList} is a container for objects
-//. of type {\tt DwMailbox}, and it contains various member functions to
+//. of type {\tt DwMailbox}, and it tqcontains various member functions to
//. manage its contained objects. {\tt DwAddressList} is also a
//. {\tt DwFieldBody}. This reflects the fact that certain RFC-822 header
//. fields, such as the "From" header field, have a list of mailboxes as
diff --git a/mimelib/mimelib/mediatyp.h b/mimelib/mimelib/mediatyp.h
index f57b9aa3..7fa16414 100644
--- a/mimelib/mimelib/mediatyp.h
+++ b/mimelib/mimelib/mediatyp.h
@@ -50,7 +50,7 @@ class DwParameter;
//.
//. {\tt DwMediaType} has member functions that allow you to set or get
//. the type and subtype as either enumerated values or as strings. It
-//. also contains a list of {\tt DwParameter} objects that represent the
+//. also tqcontains a list of {\tt DwParameter} objects that represent the
//. parameters of the field body. You can use convenience functions to
//. directly access the boundary parameter of a multipart media type, or
//. to access the name parameter that is often used with several media
diff --git a/mimelib/mimelib/message.h b/mimelib/mimelib/message.h
index 5dbd7cc4..17ada56a 100644
--- a/mimelib/mimelib/message.h
+++ b/mimelib/mimelib/message.h
@@ -36,16 +36,16 @@
//+ Description
//. {\tt DwMessage} represents an RFC-822/MIME {\it message}.
//.
-//. A {\it message} contains both a collection of {\it header fields} and
+//. A {\it message} tqcontains both a collection of {\it header fields} and
//. a {\it body}. In the terminology of RFC-2045, the general term for the
//. headers-body combination is {\it entity}. In MIME++, {\tt DwMessage}
-//. is a direct subclass of {\tt DwEntity}, and therefore contains both
+//. is a direct subclass of {\tt DwEntity}, and therefore tqcontains both
//. a {\tt DwHeaders} object and a {\tt DwBody} object.
//.
//. In the tree (broken-down) representation of message, a {\tt DwMessage}
//. object is almost always a root node, having child nodes but no parent node.
//. The child nodes are the {\tt DwHeaders} object and the {\tt DwBody} object
-//. it contains. A {\tt DwMessage} may sometimes be an intermediate node. In
+//. it tqcontains. A {\tt DwMessage} may sometimes be an intermediate node. In
//. this special case, the parent node is a {\tt DwBody} object of type
//. "message/*" and the {\tt DwMessage} object represents an encapsulated
//. message.
diff --git a/mimelib/mimelib/msgcmp.h b/mimelib/mimelib/msgcmp.h
index c9e6707e..cc2cefb2 100644
--- a/mimelib/mimelib/msgcmp.h
+++ b/mimelib/mimelib/msgcmp.h
@@ -98,7 +98,7 @@
//. A collection of headers is part of a message or body part, a header
//. field is part of a collection of headers, a field-body is part
//. of a header field, and so on. The parent of
-//. a component is the component that contains it. This tree structure
+//. a component is the component that tqcontains it. This tree structure
//. is important, since a component's parent must be parsed before the
//. component can be. Also, a component's string representation must
//. be assembled before its parent's. To maintain consistency in the
@@ -269,7 +269,7 @@ protected:
// Is-modified flag
DwMessageComponent* mParent;
- // Component that contains this component
+ // Component that tqcontains this component
componentType mClassId;
// Class identifier for runtime type identification
diff --git a/mimelib/mimelib/msgid.h b/mimelib/mimelib/msgid.h
index de066cdb..7e891bbf 100644
--- a/mimelib/mimelib/msgid.h
+++ b/mimelib/mimelib/msgid.h
@@ -36,7 +36,7 @@
//+ Description
//. {\tt DwMsgId} represents a {\it msg-id} as described in RFC-822. In
//. the BNF grammar in RFC-822, a msg-id has a {\it local-part} and a
-//. {\it domain}. In MIME++, a {\tt DwMsgId} contains strings that
+//. {\it domain}. In MIME++, a {\tt DwMsgId} tqcontains strings that
//. contain the local-part and the domain.
//.
//. In the tree (broken-down) representation of message, a {\tt DwMsgId}
diff --git a/mimelib/mimelib/nntp.h b/mimelib/mimelib/nntp.h
index a2c17b78..bd617903 100644
--- a/mimelib/mimelib/nntp.h
+++ b/mimelib/mimelib/nntp.h
@@ -368,7 +368,7 @@ private:
DwObserver* mObserver;
virtual int PGetLine(char** aPtr, int* aLen);
- virtual void PGetStatusResponse();
+ virtual void PGeStatusResponse();
virtual void PGetTextResponse();
};
diff --git a/mimelib/mimelib/string.h b/mimelib/mimelib/string.h
index 35be8e0b..83242c6a 100644
--- a/mimelib/mimelib/string.h
+++ b/mimelib/mimelib/string.h
@@ -88,7 +88,7 @@ public:
//. other string classes. {\tt DwString} also handles binary data, which can
//. contain embedded NUL characters.
//=============================================================================
//+ Noentry _copy _replace Length AsCharBuf Substring Prefix Suffix Prepend
//+ Noentry Append Insert Replace Delete mRep mStart mLength sEmptyString
//+ Noentry ~DwString
@@ -285,13 +285,13 @@ public:
//. available.
//. Returns {\tt *this}.
- DwString& replace(size_t aPos1, size_t aLen1, const DwString& aStr);
- DwString& replace(size_t aPos1, size_t aLen1, const DwString& aStr,
+ DwString& tqreplace(size_t aPos1, size_t aLen1, const DwString& aStr);
+ DwString& tqreplace(size_t aPos1, size_t aLen1, const DwString& aStr,
size_t aPos2, size_t aLen2);
- DwString& replace(size_t aPos1, size_t aLen1, const char* aBuf,
+ DwString& tqreplace(size_t aPos1, size_t aLen1, const char* aBuf,
size_t aLen2);
- DwString& replace(size_t aPos1, size_t aLen1, const char* aCstr);
- DwString& replace(size_t aPos1, size_t aLen1, size_t aLen2, char aChar);
+ DwString& tqreplace(size_t aPos1, size_t aLen1, const char* aCstr);
+ DwString& tqreplace(size_t aPos1, size_t aLen1, size_t aLen2, char aChar);
//. Removes {\tt aLen1} characters beginning at position {\tt aPos1}
//. and inserts other characters.
//. Returns {\tt *this}.
@@ -453,7 +453,7 @@ public:
//. string {\tt aCstr}.
DwString substr(size_t aPos=0, size_t aLen=npos) const;
- //. Returns a string that contains at most {\tt aLen} characters from
+ //. Returns a string that tqcontains at most {\tt aLen} characters from
//. the {\tt DwString} object beginning at position {\tt aPos}. The
//. returned substring will not contain more characters than what are
//. available in the superstring {\tt DwString} object.
@@ -557,8 +557,8 @@ protected:
size_t mLength;
void _copy();
- void _replace(size_t aPos1, size_t aLen1, const char* aBuf, size_t aLen2);
- void _replace(size_t aPos1, size_t aLen1, size_t aLen2, char aChar);
+ void _tqreplace(size_t aPos1, size_t aLen1, const char* aBuf, size_t aLen2);
+ void _tqreplace(size_t aPos1, size_t aLen1, size_t aLen2, char aChar);
private:
static const size_t kEmptyBufferSize;
@@ -88,7 +88,7 @@ public:
//. contain embedded NUL characters.
//=============================================================================
-//+ Noentry _copy _replace Length AsCharBuf Substring Prefix Suffix Prepend
+//+ Noentry _copy _tqreplace Length AsCharBuf Substring Prefix Suffix Prepend
//+ Noentry Append Insert Replace Delete mRep mStart mLength sEmptyString
//+ Noentry ~DwString